function [ u ] = u_solve(k, h, n_upper, j_upper)
%U_SOLVE Solves the initial-boundary value problem using the Lax-Wendroff
%explicit scheme

%Input:
%k is the step size in time
%h is the step size in space
%n_upper is the stopping index in time for the explicit scheme
%j_upper is the stopping index in space for the explicit scheme

%Output:
%u is the matrix of approximate solutions

c = k/h;

%Initializes the matrix of approximate solutions
u = zeros(n_upper, j_upper);

for n = 1:n_upper
    
    for j = 1:j_upper
        
        %This is the Lax-Wendroff scheme:
        u(n, j) = u_function(k, h, n-1, j, u) - (c/2)*(u_function(k, h, n-1, j+1, u) - u_function(k, h, n-1, j-1, u)) + ((c^2)/2)*(u_function(k, h, n-1, j+1, u) - 2*u_function(k, h, n-1, j, u) + u_function(k, h, n-1, j-1, u));
        
    end;
    
end;

end